#
# spec file for package mawk
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mawk
Version:        1.3.4
Release:        27.5
Summary:        Implementation of New/POSIX AWK
License:        GPL-2.0
Group:          Productivity/Text/Utilities
Url:            http://invisible-island.net/mawk/mawk.html
Source0:        ftp://invisible-island.net/mawk/mawk-%{version}.tgz
Source1:        ftp://invisible-island.net/mawk/mawk-%{version}.tgz.asc
Source2:        %{name}.keyring
# PATCH-FIX-UPSTREAM mawk-1.3.4-fix-make-check-path-handling.patch gber@opensuse.org -- Modifies makefile and mawktest to use relative paths
Patch0:         mawk-1.3.4-fix-make-check-path-handling.patch
# PATCH-FIX-UPSTREAM mawk-1.3.4-fix-regex-matching.patch bnc#740484 gber@opensuse.org -- Adds limit-check after processing match(test, "[^0-9A-Za-z]") to ensure the internal trailing null of the test-string is not mistaken for part of the string
Patch1:         mawk-1.3.4-fix-regex-matching.patch
BuildRequires:  update-alternatives
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
mawk is an interpreter for the AWK Programming Language. It implements the AWK
language as defined in Aho, Kernighan and Weinberger, The AWK  Programming
Language, Addison-Wesley Publishing, 1988. Furthermore, it conforms to the
POSIX 1003.2 (draft 11.3) definition of the AWK language and additionally
provides a small number of extensions.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
chmod 755 examples/*

%build
# without --enable-warnings several functions will not be marked with gcc's
# noreturn attribute and produce warnings when $RPM_OPT_FLAGS contains -Wall
%configure \
    --enable-warnings
make %{?_smp_mflags}

%install
%make_install

# compatibility symlink
install -d -m 755 %{buildroot}/bin
ln -s %{_bindir}/mawk %{buildroot}/bin/mawk
# create symlinks for update-alternatives
install -d -m 755 %{buildroot}%{_sysconfdir}/alternatives
ln -s %{_sysconfdir}/alternatives/awk %{buildroot}/bin/awk
ln -s %{_sysconfdir}/alternatives/usr-bin-awk %{buildroot}%{_bindir}/awk
ln -s %{_sysconfdir}/alternatives/awk.1%{?ext_man} %{buildroot}%{_mandir}/man1/awk.1%{?ext_man}

%check
make %{?_smp_mflags} check

%post
%{_sbindir}/update-alternatives \
  --install /bin/awk awk %{_bindir}/mawk 15 \
  --slave %{_bindir}/awk usr-bin-awk %{_bindir}/mawk \
  --slave %{_mandir}/man1/awk.1.gz awk.1%{?ext_man} %{_mandir}/man1/mawk.1%{?ext_man}

%preun
if [ $1 -eq 0 ]; then
    %{_sbindir}/update-alternatives --remove awk %{_bindir}/mawk
fi

%files
%defattr(-,root,root,-)
%doc ACKNOWLEDGMENT CHANGES COPYING README examples/
/bin/mawk
%{_bindir}/mawk
%{_mandir}/man1/mawk.1%{?ext_man}
/bin/awk
%{_bindir}/awk
%{_mandir}/man1/awk.1%{?ext_man}
%ghost %{_sysconfdir}/alternatives/awk
%ghost %{_sysconfdir}/alternatives/usr-bin-awk
%ghost %{_sysconfdir}/alternatives/awk.1%{?ext_man}

%changelog
* Sat Apr  4 2015 mpluskal@suse.com
- Add gpg signature
- Cleanup spec file with spec-cleaner
* Sat Feb  8 2014 gber@opensuse.org
- adjust update-alternative usage to packaging policy
  (see http://lists.opensuse.org/opensuse-packaging/2014-02/msg00024.html)
- move mawk to /usr/bin and add symlink in /bin
* Tue May 15 2012 gber@opensuse.org
- package COPYING
- simplify installation
- make example scripts executable
* Tue Jan 10 2012 gber@opensuse.org
- added mawk-1.3.4-fix-regex-matching.patch which adds limit-check
  after processing match(test, "[^0-9A-Za-z]") to ensure the
  internal trailing null of the test-string is not mistaken for
  part of the string (backported from development snapshot,
  bnc#740484)
- specfile cleanup
* Mon Feb 22 2010 guido+opensuse.org@berhoerster.name
- use update-alternatives
* Fri Feb 19 2010 guido+opensuse.org@berhoerster.name
- add copyright note for integration into Factory
* Fri Feb 19 2010 guido+opensuse.org@berhoerster.name
- cleaned up specfile, added explanatory comment
* Wed Feb 17 2010 guido+opensuse.org@berhoerster.name
- added check section
- use external changelog
- dropped mawk-1.3.4-fix-gcc-bogus-warning.patch, passing --enable-warnings to
  configure correctly marks the affected functions with GCC's noreturn
  attribute (thanks to T. Dickey for clarifying)
- added patch fixing path handling issues with the make check target and
  associated scripts
* Wed Dec 23 2009 guido+opensuse.org@berhoerster.name
- initial packaging of mawk
